@@ -5,6 +5,7 @@ Provides frozendict, a simple immutable dictionary.
 try:
     from ._frozendict import *
     c_ext = True
+    # noinspection PyUnresolvedReferences
     del _frozendict
 except ImportError:
     from ._frozendict_py import *
@@ -12,27 +13,24 @@ except ImportError:
 
 from .version import version as __version__
 from . import monkeypatch
+from .cool import *
 
 
 def _getFrozendictJsonEncoder(BaseJsonEncoder = None):
-    if BaseJsonEncoder == None:
+    if BaseJsonEncoder is None:
         from json.encoder import JSONEncoder
         
-        
         BaseJsonEncoder = JSONEncoder
     
-    
-    class FrozendictJsonEncoder(BaseJsonEncoder):
+    class FrozendictJsonEncoderInternal(BaseJsonEncoder):
         def default(self, obj):
             if isinstance(obj, frozendict):
                 # TODO create a C serializer
                 return dict(obj)
             
-            
             return BaseJsonEncoder.default(self, obj)
     
-    
-    return FrozendictJsonEncoder
+    return FrozendictJsonEncoderInternal
 
 
 FrozendictJsonEncoder = _getFrozendictJsonEncoder()
@@ -40,6 +38,8 @@ monkeypatch.patchOrUnpatchAll(patch = True, warn = False)
 
 
 from collections.abc import Mapping
+
+# noinspection PyUnresolvedReferences
 Mapping.register(frozendict)
 del Mapping
 
@@ -53,4 +53,7 @@ else:
 # TODO deprecated, to remove in future versions
 FrozenOrderedDict = frozendict
 
+__all__ += cool.__all__
 __all__ += (FrozendictJsonEncoder.__name__, "FrozenOrderedDict")
+
+del cool
